\name{Zmax}
\alias{Zmax}
\title{A Robust and Powerful Test for Case-Control Genetic Association Study on X Chromosome}
\usage{Zmax(data, method="rmbs")}
\description{
A robust and powerful approach for association analysis on X chromosome based on case-control data, which takes account of different dosage compensation patterns. Moreover, it requires neither specifying the underlying genetic models nor the assumption of Hardy-Weinberg equilibrium.
}
\arguments{
  \item{data}{A 2x5 contingency table in matrix form. The first row is for cases and the second one is for controls. The first three columns are the number of females  carrying 0, 1 and 2 copies of the reference allele, respectively. The last two columns are the number of males carrying 0 and 1 copies of the reference allele, respectively.}
  \item{method}{The method for calculating the p value, either "rmbs" (rhombus formula) or "norm" (bivariate normal integral). Note that the default method for this option is "rmbs".}
}
\value{
\item{statistic}{The value of the test statistic Zmax.}
\item{p.value}{The p value of Zmax.}
\item{method}{A character string indicating the method for calculating the p value.}
}
\note{
The Zmax function will use R package "mvtnorm", therefore, please make sure that the package has been installed and loaded into R before using this function.
}
\author{Peng Wang and Si-Qi Xu}
\references{
Peng Wang, Si-Qi Xu, Bei-Qi Wang, Wing Kam Fung and Ji-Yuan Zhou. 2018 A Robust and Powerful Test for Case-Control Genetic Association Study on X Chromosome. (submitted)
}
\examples{
data <- rbind(c(46,62,28,30,29),c(78,75,37,22,7))
result <- Zmax(data,method="rmbs")
result
}
